from reasoner.database.database_repository.models import *
from reasoner.database.database_supervisor.models import *

import hashlib
import logging

logger = logging.getLogger("glimpse.default")

# helper
def get_method(task_id):
    queryset = Task.objects.all().filter(id=task_id).values_list('method', flat=True)
    if not queryset:
        return "null"
    else:
        return queryset[0]

# REASONER
class Reasoner:
    @staticmethod
    def reason(report):
        method = get_method(report.task_id)

        # select reasoner
        if method == "traceroute":
            TracerouteReasoner.reason(report)
        else:
            return


class TracerouteReasoner:
    @staticmethod
    def reason(report):
        # check if we reason for this task_id
        try:
            traceroute_reasoning_task = TracerouteReasoningTasks.objects.get(active=True, task_id=report.task_id)
        except:
            # no log message as this might just be a task we don't reason with
            return

        # get already found paths
        path_ids = list(TracerouteReasoningPaths.objects.filter(report__task_id=report.task_id, report__user=report.user, report__device=report.device).values_list('pathId', flat=True))

        # get traceroutes for this report
        traceroutes = TracerouteResult.objects.filter(report=report)

        new_path_found = False

        # check if we found new paths and save them
        for traceroute in traceroutes:
            # get path-id
            path_id = TracerouteReasoner._path_id(traceroute.id)
            if path_id not in path_ids:
                new_path_found = True
                path_ids.append(path_id)
                TracerouteReasoningPaths(pathId=path_id, report=report).save()

        # if we found new paths, schedule again by reactivating the schedule
        if new_path_found:
            TracerouteReasoner._reactive_schedules(traceroute_reasoning_task.schedules.split(','), report)

    @staticmethod
    def _path_id(traceroute_id):
        ips = TracerouteHopResult.objects.filter(traceroute=traceroute_id).values_list('ip', flat=True)

        h = hashlib.md5()
        h.update(str(ips).encode())
        return h.hexdigest()

    @staticmethod
    def _reactive_schedules(schedule_ids, report):
        # delete the deliveries for the schedules
        for schedule_id in schedule_ids:
            try:
                ScheduleDelivered.objects.get(schedule_id=schedule_id,
                                              user=report.user,
                                              device=report.device).delete()
            except:
                logger.warning("No deliveries found for schedule")
                continue
