from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _


class DeviceGroup(models.Model):
    name = models.TextField()
    description = models.TextField(null=True)

    class Meta:
        verbose_name = _("Device Group")


class Device(models.Model):
    device_id = models.CharField(_("Device ID"), max_length=64, db_index=True, help_text=_("Uniq identifier from this device"))
    user = models.ForeignKey(User, verbose_name=_("User"))
    is_active = models.BooleanField(_("Is active"), default=True)

    created = models.DateTimeField(_("Created at"), auto_now_add=True)
    created_ip = models.GenericIPAddressField(_("Created from IP"))
    modified = models.DateTimeField(_("Last modified at"), auto_now=True)
    modified_ip = models.GenericIPAddressField(_("Last modified from IP"))

    app_version = models.TextField(_("App version"), blank=True, default="")
    platform = models.TextField(blank=True, default="")
    os = models.TextField(_("OS"), help_text=_("E.g. Windows, Mac, Linux, Android, iOS, ..."), blank=True, default="")
    os_version = models.TextField(_("OS version"), blank=True, default="")
    firmware_version = models.TextField(_("Firmware version"), blank=True, default="")
    manufacturer = models.TextField(_("Manufacture"), blank=True, default="")
    board = models.TextField(_("Board"), blank=True, default="")
    model = models.TextField(_("Model"), blank=True, default="")
    visible = models.BooleanField(_("Invisible"), default=True)
    name = models.TextField(_("Name"), blank=True, default="")
    description = models.TextField(_("Description"), blank=True, default="")

    group = models.ForeignKey(DeviceGroup, null=True)

    def __str__(self):
        return self.device_id

    class Meta:
        verbose_name = _("Device")
        verbose_name_plural = _("Devices")


class DeviceSessionKey(models.Model):
    session_key = models.CharField(_("Session key"), max_length=40, primary_key=True)
    expire_date = models.DateTimeField(_("Expiry date"), db_index=True)
    is_active = models.BooleanField(_("Is active"), default=True)
    last_activity = models.DateTimeField(_("Last activity at"), auto_now=True)

    user = models.ForeignKey(User, verbose_name=_("User"))
    device = models.ForeignKey(Device, verbose_name=_("Device") )

    class Meta:
        verbose_name = _("Session")
        verbose_name_plural = _("Sessions")