# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Channel',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('target', models.TextField()),
                ('certificate', models.TextField()),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Channel',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='ClientPrecondition',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('on_wireless', models.NullBooleanField(verbose_name='Run on wireless network', default=True)),
                ('on_wire', models.NullBooleanField(verbose_name='Run on wire network', default=True)),
                ('on_cellular', models.NullBooleanField(verbose_name='Run on cellular network', default=True)),
                ('on_location_lat', models.FloatField(default=0.0)),
                ('on_location_long', models.FloatField(default=0.0)),
                ('on_location_radius', models.IntegerField(default=0)),
                ('min_charge', models.PositiveSmallIntegerField(default=0)),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Client Precondition',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Configuration',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('config_channel', models.ForeignKey(to='database_supervisor.Channel', related_name='+')),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
                ('keepalive_channel', models.ForeignKey(to='database_supervisor.Channel', related_name='+')),
                ('report_channel', models.ForeignKey(to='database_supervisor.Channel', related_name='+')),
                ('supervisor_channel', models.ForeignKey(to='database_supervisor.Channel', related_name='+')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Configuration',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='DevicePrecondition',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('is_android', models.NullBooleanField()),
                ('is_ios', models.NullBooleanField()),
                ('is_phone', models.NullBooleanField()),
                ('is_console', models.NullBooleanField()),
                ('is_tablet', models.NullBooleanField()),
                ('is_windows', models.NullBooleanField()),
                ('is_linux', models.NullBooleanField()),
                ('is_mac', models.NullBooleanField()),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Device Precondition',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Schedule',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('excepted_results', models.TextField()),
                ('on_success', models.TextField()),
                ('on_failure', models.TextField()),
                ('channel', models.ForeignKey(to='database_supervisor.Channel', verbose_name='Channel')),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
                ('precondition', models.ForeignKey(to='database_supervisor.ClientPrecondition', verbose_name='Client Precondition')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Schedule',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Task',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('method', models.TextField()),
                ('active', models.BooleanField(default=False)),
                ('created_by', models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TaskOption',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TaskOptionBTC',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('type', models.CharField(choices=[('up', 'upstream'), ('down', 'downstream')], max_length=100)),
                ('host', models.CharField(max_length=64)),
                ('port', models.IntegerField(default=5105)),
                ('initial_data_size', models.IntegerField(default=1048576)),
                ('slices', models.IntegerField(default=10)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: BTC',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionDnsLookup',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('host', models.CharField(max_length=128)),
                ('dns_server', models.CharField(blank=True, max_length=128)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: DNS Lookup',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionHttpDownload',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('url', models.CharField(max_length=256)),
                ('cache_test', models.BooleanField(default=False)),
                ('threads', models.IntegerField(default=1)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: HTTP Download',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionPacketTrains',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('host', models.CharField(max_length=128)),
                ('port', models.IntegerField(default=5105)),
                ('packet_size', models.IntegerField(default=1000)),
                ('train_length', models.IntegerField(default=48)),
                ('iterations', models.IntegerField(default=1)),
                ('rate_min', models.BigIntegerField(default=10485760)),
                ('rate_max', models.BigIntegerField(default=262144000)),
                ('delay', models.BigIntegerField(default=200000000)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: Packet Train',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionPing',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('type', models.CharField(choices=[('System', 'System'), ('Tcp', 'Tcp'), ('Udp', 'Udp')], max_length=20)),
                ('host', models.CharField(max_length=128)),
                ('count', models.IntegerField(default=4)),
                ('timeout', models.IntegerField(default=1000)),
                ('interval', models.IntegerField(default=200)),
                ('ttl', models.IntegerField(default=64)),
                ('destination_port', models.IntegerField(default=33434)),
                ('source_port', models.IntegerField(default=33434)),
                ('payload', models.IntegerField(default=74)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: Ping',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionReverseDnsLookup',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('ip', models.CharField(max_length=128)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: Reverse DNS Lookup',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionTraceroute',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
                ('host', models.CharField(max_length=128)),
                ('count', models.IntegerField(default=3)),
                ('interval', models.IntegerField(default=1000)),
                ('receive_timeout', models.IntegerField(default=1000)),
                ('destination_port', models.IntegerField(default=33434)),
                ('source_port', models.IntegerField(default=33434)),
                ('payload', models.IntegerField(default=74)),
                ('ping_type', models.CharField(choices=[('System', 'System'), ('Tcp', 'Tcp'), ('Udp', 'Udp')], max_length=20)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: Traceroute',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='TaskOptionUPnP',
            fields=[
                ('taskoption_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.TaskOption', serialize=False)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Task Option: UPnP',
            },
            bases=('database_supervisor.taskoption',),
        ),
        migrations.CreateModel(
            name='Timing',
            fields=[
                ('id', models.AutoField(primary_key=True, auto_created=True, verbose_name='ID', serialize=False)),
                ('name', models.CharField(max_length=255)),
                ('description', models.TextField(blank=True)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='TimingCalendar',
            fields=[
                ('timing_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.Timing', serialize=False)),
                ('start', models.DateTimeField()),
                ('end', models.DateTimeField()),
                ('months', models.IntegerField()),
                ('weekdays', models.IntegerField()),
                ('days', models.IntegerField()),
                ('hours', models.IntegerField()),
                ('minutes', models.IntegerField()),
                ('seconds', models.IntegerField()),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing Calender',
            },
            bases=('database_supervisor.timing',),
        ),
        migrations.CreateModel(
            name='TimingImmediate',
            fields=[
                ('timing_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.Timing', serialize=False)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing Immediate',
            },
            bases=('database_supervisor.timing',),
        ),
        migrations.CreateModel(
            name='TimingOnDemand',
            fields=[
                ('timing_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.Timing', serialize=False)),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing On Demand',
            },
            bases=('database_supervisor.timing',),
        ),
        migrations.CreateModel(
            name='TimingOneOff',
            fields=[
                ('timing_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.Timing', serialize=False)),
                ('time', models.DateTimeField()),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing OneOff',
            },
            bases=('database_supervisor.timing',),
        ),
        migrations.CreateModel(
            name='TimingPeriodic',
            fields=[
                ('timing_ptr', models.OneToOneField(auto_created=True, parent_link=True, primary_key=True, to='database_supervisor.Timing', serialize=False)),
                ('start', models.DateTimeField()),
                ('end', models.DateTimeField()),
                ('interval', models.IntegerField()),
            ],
            options={
                'abstract': False,
                'verbose_name': 'Timing Periodic',
            },
            bases=('database_supervisor.timing',),
        ),
        migrations.AddField(
            model_name='timing',
            name='created_by',
            field=models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='taskoption',
            name='created_by',
            field=models.ForeignKey(to=settings.AUTH_USER_MODEL, verbose_name='User'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='task',
            name='options',
            field=models.ForeignKey(to='database_supervisor.TaskOption', verbose_name='Task Option'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='schedule',
            name='task',
            field=models.ForeignKey(to='database_supervisor.Task', verbose_name='Task'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='schedule',
            name='timing',
            field=models.ForeignKey(to='database_supervisor.Timing', verbose_name='Timing'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='channel',
            name='timing',
            field=models.ForeignKey(to='database_supervisor.Timing', verbose_name='Timing'),
            preserve_default=True,
        ),
    ]
